:orphan:

#########
Reference
#########

Autogenerated summary of the modules, functions and classes in :py:mod:`xyzpy`.

.. autosummary::
    :toctree: _autosummary

    xyzpy
    xyzpy.gen
    xyzpy.gen.prepare
    xyzpy.gen.combo_runner
    xyzpy.gen.case_runner
    xyzpy.gen.farming
    xyzpy.gen.cropping
    xyzpy.plot
    xyzpy.plot.color
    xyzpy.plot.core
    xyzpy.plot.marker
    xyzpy.plot.plotter_bokeh
    xyzpy.plot.plotter_matplotlib
    xyzpy.plot.xyz_cmaps
